@@ -114,8 +114,7 @@
 #' ## Train h2o NNET --------------------------------------------------------------
 #' # Create a cluster with 4 available cores
 #' h2o::h2o.init(ip = "localhost",
-#'               nthreads = 4,
-#'               max_mem_size = "2g")
+#'               nthreads = 4)
 #'
 #' # Reset the cluster
 #' h2o::h2o.removeAll()
@@ -154,7 +153,8 @@
 #'
 #' # Try SensAnalysisMLP
 #' trData <- nntrData
-#' NeuralSens::SensAnalysisMLP(neuralmod, trData = trData, output_name = "DEM",actfunc = c("linear","sigmoid","linear"))
+#' NeuralSens::SensAnalysisMLP(neuralmod, trData = trData, output_name = "DEM",
+#'                             actfunc = c("linear","sigmoid","linear"))
 #'
 #' ## Train RSNNS NNET ------------------------------------------------------------
 #' # Normalize data using RSNNS algorithms
@@ -171,30 +171,9 @@
 #' # Try SensAnalysisMLP
 #' NeuralSens::SensAnalysisMLP(RSNNSmod, trData = trData, output_name = "DEM")
 #'
-#' ## TRAIN neuralnet NNET --------------------------------------------------------
-#' # Create a formula to train NNET
-#' form <- paste(names(fdata.Reg.tr)[2:ncol(fdata.Reg.tr)], collapse = " + ")
-#' form <- formula(paste(names(fdata.Reg.tr)[1], form, sep = " ~ "))
-#'
-#' set.seed(150)
-#' nnmod <- neuralnet::neuralnet(form,
-#'                                    nntrData,
-#'                                    linear.output = TRUE,
-#'                                    rep = 1,
-#'                                    hidden = hidden_neurons,
-#'                                    lifesign = "minimal",
-#'                                    threshold = 7,
-#'                                    stepmax = iters,
-#'                                    learningrate = decay,
-#'                                    act.fct = "tanh")
-#'
-#' # Try SensAnalysisMLP
-#' NeuralSens::SensAnalysisMLP(nnmod)
-#'
-#'
 #' ## USE DEFAULT METHOD ----------------------------------------------------------
 #' NeuralSens::SensAnalysisMLP(caretmod$finalModel$wts,
-#'                             trData = fdata.Reg.tv,
+#'                             trData = fdata.Reg.tr,
 #'                             mlpstr = caretmod$finalModel$n,
 #'                             coefnames = caretmod$coefnames,
 #'                             actfun = c("linear","sigmoid","linear"),
@@ -243,8 +222,7 @@
 #' ## Train h2o NNET --------------------------------------------------------------
 #' # Create local cluster with 4 available cores
 #' h2o::h2o.init(ip = "localhost",
-#'               nthreads = 4,
-#'               max_mem_size = "2g")
+#'               nthreads = 4)
 #'
 #' # Reset the cluster
 #' h2o::h2o.removeAll()
@@ -273,52 +251,6 @@
 #' h2o::h2o.shutdown(prompt = FALSE)
 #' rm(fdata_h2o)
 #'
-#' ## Train neural NNET -----------------------------------------------------------
-#' # set.seed(150)
-#' # neuralmod <-mlptrain(as.matrix(nntrData[,2:ncol(nntrData)]),
-#' #                           hidden_neurons,
-#' #                           as.matrix(nntrData[1]),
-#' #                           it=iters,
-#' #                           visual=FALSE)
-#' #
-#' # # Try SensAnalysisMLP
-#' # NeuralSens::SensAnalysisMLP(neuralmod, trData = trData)
-#'
-#' # ## Train RSNNS NNET ------------------------------------------------------------
-#' # # Normalize data using RSNNS algorithms
-#' # trData <- as.data.frame(RSNNS::normalizeData(fdata.Reg.cl))
-#' # names(trData) <- names(fdata.Reg.tr)
-#' # set.seed(150)
-#' # RSNNSmod <- RSNNS::mlp(x = trData[,2:ncol(trData)],
-#' #                      y = trData[,1],
-#' #                      size = hidden_neurons,
-#' #                      linOut = FALSE,
-#' #                      learnFuncParams=c(decay),
-#' #                      maxit=iters)
-#' #
-#' # # Try SensAnalysisMLP
-#' # NeuralSens::SensAnalysisMLP(RSNNSmod, trData = trData, output_name = "DEM")
-#'
-#' ## TRAIN neuralnet NNET --------------------------------------------------------
-#' # Create a formula to train NNET
-#' # form <- paste(names(fdata.Reg.tr)[2:ncol(fdata.Reg.tr)], collapse = " + ")
-#' # form <- formula(paste(names(fdata.Reg.tr)[1], form, sep = " ~ "))
-#' #
-#' # set.seed(150)
-#' # nnmod <- neuralnet(form,
-#' #                    nntrData,
-#' #                    linear.output = FALSE,
-#' #                    rep = 1,
-#' #                    hidden = hidden_neurons,
-#' #                    lifesign = "minimal",
-#' #                    threshold = 4,
-#' #                    stepmax = iters,
-#' #                    learningrate = decay,
-#' #                    act.fct = "tanh")
-#' #
-#' # # Try SensAnalysisMLP
-#' # NeuralSens::SensAnalysisMLP(nnmod)
-#'
 #' ## TRAIN nnet NNET --------------------------------------------------------
 #' # Create a formula to train NNET
 #' form <- paste(names(fdata.Reg.tr)[2:ncol(fdata.Reg.tr)], collapse = " + ")
@@ -962,9 +894,8 @@ SensAnalysisMLP.list <- function(MLP.fit,
     actfunc <- c("linear",
                  ifelse(actfunc == 1, "sigmoid",
                         ifelse(actfunc == 2, "tanh",
-                               ifelse(actfunc == 3, "Gauss",
-                                      ifelse(actfunc == 4, "linear"
-                                      )))))
+                               ifelse(actfunc == 3, "Gauss", "linear"
+                                      ))))
   }
 
   SensAnalysisMLP.default(finalModel,
